@@ -3,7 +3,6 @@
 """
 import json
 import time
-import uuid
 import importlib
 from loguru import logger
 from palp import settings
@@ -15,8 +14,9 @@ from palp.tool.client_heart import ClientHeart
 from requests.cookies import RequestsCookieJar
 from palp.tool.short_module import import_module
 from palp.sequence.sequence_redis_item import FIFOItemRedisSequence
-from palp.decorator.decorator_run_func_by_thread import RunByThread
 from palp.decorator.decorator_spider_wait import SpiderWaitDecorator
+from palp.decorator.decorator_spider_record import SpiderRecordDecorator
+from palp.decorator.decorator_run_func_by_thread import RunByThreadDecorator
 from palp.decorator.decorator_spider_middleware import SpiderMiddlewareDecorator
 
 
@@ -92,7 +92,7 @@ class DistributiveSpider(Spider):
             elif time.time() - json.loads(heart_beat.decode())['time'] > 20:
                 redis_conn.delete(settings.REDIS_KEY_MASTER)
 
-    @RunByThread(daemon=True)
+    @RunByThreadDecorator(daemon=True)
     def start_distribute_failed_request(self):
         """
         重新放入 执行失败的请求任务
@@ -152,7 +152,7 @@ class DistributiveSpider(Spider):
 
                 self.queue.put(request)
 
-    @RunByThread(daemon=True)
+    @RunByThreadDecorator(daemon=True)
     def start_distribute_failed_item(self) -> None:
         """
         重新放入 处理失败的 item
@@ -197,12 +197,12 @@ class DistributiveSpider(Spider):
             # 设置 master 标志
             self.spider_master = True
             redis_conn.set(settings.REDIS_KEY_MASTER, json.dumps({
-                'name': str(uuid.uuid1().hex.encode()),
+                'name': self.spider_uuid,
                 'time': time.time(),
             }, ensure_ascii=False))
 
-            # 删除停止标志
-            redis_conn.delete(settings.REDIS_KEY_STOP)
+            # 删除停止标志、记录
+            redis_conn.delete(settings.REDIS_KEY_STOP, settings.REDIS_KEY_RECORD)
 
             # 清空心跳
             redis_conn.delete(settings.REDIS_KEY_HEARTBEAT, settings.REDIS_KEY_HEARTBEAT_FAILED)
@@ -215,6 +215,7 @@ class DistributiveSpider(Spider):
             self.start_distribute()
 
     @SpiderMiddlewareDecorator()
+    @SpiderRecordDecorator()
     @SpiderWaitDecorator()
     def run(self) -> None:
         """
